@@ -23,8 +23,3 @@ pub mod errors;
 mod request;
 
 pub use crate::definitions::*;
-
-#[cfg(feature = "sync")]
-pub(crate) type Rc<T> = std::sync::Arc<T>;
-#[cfg(not(feature = "sync"))]
-pub(crate) type Rc<T> = std::rc::Rc<T>;
